sha256_password_rsa

Function sha256_password_rsa 

pub fn sha256_password_rsa(
    password: &str,
    seed: &[u8],
    public_key_pem: &[u8],
    use_oaep: bool,
) -> Result<Vec<u8>, String>
Scramble password for sha256_password plugin using RSA encryption.

This is used when full authentication is required for caching_sha2_password or sha256_password plugins without TLS.

Arguments

  • password - The user’s password
  • seed - The authentication seed from server
  • public_key - RSA public key from server (PEM format)

Returns

The encrypted password, or error if encryption fails.

This is used for full authentication for caching_sha2_password/sha256_password when the connection is not secured by TLS.