xor_password_with_seed

Function xor_password_with_seed 

pub fn xor_password_with_seed(password: &str, seed: &[u8]) -> Vec<u8> 
XOR password with seed for cleartext transmission over TLS.

When the connection is secured with TLS, some auth methods allow sending the password XOR’d with the seed (or even cleartext).