MySqlConfig

Struct MySqlConfig 

pub struct MySqlConfig {
Show 13 fields pub host: String, pub port: u16, pub user: String, pub password: Option<String>, pub database: Option<String>, pub charset: u8, pub connect_timeout: Duration, pub ssl_mode: SslMode, pub tls_config: TlsConfig, pub compression: bool, pub attributes: HashMap<String, String>, pub local_infile: bool, pub max_packet_size: u32,
}
MySQL connection configuration.

Fields

host: String

Hostname or IP address

port: u16

Port number (default: 3306)

user: String

Username for authentication

password: Option<String>

Password for authentication

database: Option<String>

Database name to connect to (optional at connect time)

charset: u8

Character set (default: utf8mb4)

connect_timeout: Duration

Connection timeout

ssl_mode: SslMode

SSL mode

tls_config: TlsConfig

TLS configuration (certificates, keys, etc.)

compression: bool

Enable compression (CLIENT_COMPRESS capability)

attributes: HashMap<String, String>

Additional connection attributes

local_infile: bool

Local infile handling (disabled by default for security)

max_packet_size: u32

Max allowed packet size (default: 64MB)

Implementations

Source

impl MySqlConfig

pub fn new() -> Self

Create a new configuration with default values.

pub fn host(self, host: impl Into<String>) -> Self

Set the hostname.

pub fn port(self, port: u16) -> Self

Set the port.

pub fn user(self, user: impl Into<String>) -> Self

Set the username.

pub fn password(self, password: impl Into<String>) -> Self

Set the password.

pub fn database(self, database: impl Into<String>) -> Self

Set the database.

pub fn charset(self, charset: u8) -> Self

Set the character set.

pub fn connect_timeout(self, timeout: Duration) -> Self

Set the connection timeout.

pub fn ssl_mode(self, mode: SslMode) -> Self

Set the SSL mode.

pub fn tls_config(self, config: TlsConfig) -> Self

Set the TLS configuration.

pub fn ca_cert(self, path: impl Into<PathBuf>) -> Self

Set the CA certificate path for TLS.

This is a convenience method equivalent to:

config.tls_config(TlsConfig::new().ca_cert(path))
pub fn client_cert( self, cert_path: impl Into<PathBuf>, key_path: impl Into<PathBuf>, ) -> Self

Set client certificate and key paths for mutual TLS.

Both cert and key must be provided for client authentication.

pub fn compression(self, enabled: bool) -> Self

Enable or disable compression.

pub fn attribute(self, key: impl Into<String>, value: impl Into<String>) -> Self

Set a connection attribute.

pub fn local_infile(self, enabled: bool) -> Self

Enable or disable local infile handling.

Security Warning

Enabling local infile can be a security risk. Only enable if you trust the server and understand the implications.

pub fn max_packet_size(self, size: u32) -> Self

Set the max allowed packet size.

pub fn socket_addr(&self) -> String

Get the socket address string for connection.

pub fn capability_flags(&self) -> u32

Build capability flags based on configuration.