pub fn decode_text_value(
field_type: FieldType,
data: &[u8],
is_unsigned: bool,
) -> ValueExpand description
Decode a text protocol value to a sqlmodel Value.
In text protocol, all values are transmitted as strings. This function parses the string based on the column type.